check_one_hot_matrix: Check one-hot matrix

View source: R/check_one_hot_matrix.R

check_one_hot_matrixR Documentation

Check one-hot matrix

Description

These functions check whether the input is a one-hot matrix, i.e., a numeric matrix where each row contains exactly one entry equal to 1 and all other entries equal to 0.

Usage

check_one_hot_matrix(
  x,
  nrows = NULL,
  ncols = NULL,
  tolerance = sqrt(.Machine$double.eps)
)

assert_one_hot_matrix(
  x,
  nrows = NULL,
  ncols = NULL,
  tolerance = sqrt(.Machine$double.eps),
  .var.name = checkmate::vname(x),
  add = NULL
)

test_one_hot_matrix(
  x,
  nrows = NULL,
  ncols = NULL,
  tolerance = sqrt(.Machine$double.eps)
)

Arguments

x

[any]
Object to check.

nrows

[integer(1)]
Exact number of rows.

ncols

[integer(1)]
Exact number of columns.

tolerance

[numeric(1)]
A non-negative tolerance value.

.var.name

[character(1)]
Name of the checked object to print in assertions. Defaults to the heuristic implemented in vname.

add

[AssertCollection]
Collection to store assertion messages. See AssertCollection.

Value

Same as documented in check_matrix.

See Also

Other matrix helpers: check_correlation_matrix(), check_covariance_matrix(), check_transition_probability_matrix(), cov_to_chol(), diff_cov(), insert_matrix_column(), matrix_diagonal_indices(), matrix_indices(), sample_correlation_matrix(), sample_covariance_matrix(), sample_transition_probability_matrix(), stationary_distribution()

Examples

x <- matrix(c(
  1, 0, 0, 0,
  0, 1, 0, 0,
  0, 0, 0, 0
), nrow = 3, byrow = TRUE)

check_one_hot_matrix(x)
test_one_hot_matrix(x)
## Not run: 
assert_one_hot_matrix(x)

## End(Not run)

oeli documentation built on April 23, 2026, 9:07 a.m.