View source: R/check_one_hot_matrix.R
| check_one_hot_matrix | R Documentation |
These functions check whether the input is a one-hot matrix, i.e., a
numeric matrix where each row contains exactly one entry equal to 1 and
all other entries equal to 0.
check_one_hot_matrix(
x,
nrows = NULL,
ncols = NULL,
tolerance = sqrt(.Machine$double.eps)
)
assert_one_hot_matrix(
x,
nrows = NULL,
ncols = NULL,
tolerance = sqrt(.Machine$double.eps),
.var.name = checkmate::vname(x),
add = NULL
)
test_one_hot_matrix(
x,
nrows = NULL,
ncols = NULL,
tolerance = sqrt(.Machine$double.eps)
)
x |
[ |
nrows |
[ |
ncols |
[ |
tolerance |
[ |
.var.name |
[ |
add |
[ |
Same as documented in check_matrix.
Other matrix helpers:
check_correlation_matrix(),
check_covariance_matrix(),
check_transition_probability_matrix(),
cov_to_chol(),
diff_cov(),
insert_matrix_column(),
matrix_diagonal_indices(),
matrix_indices(),
sample_correlation_matrix(),
sample_covariance_matrix(),
sample_transition_probability_matrix(),
stationary_distribution()
x <- matrix(c(
1, 0, 0, 0,
0, 1, 0, 0,
0, 0, 0, 0
), nrow = 3, byrow = TRUE)
check_one_hot_matrix(x)
test_one_hot_matrix(x)
## Not run:
assert_one_hot_matrix(x)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.